@@ -2,7 +2,7 @@ from quant.dom.base import DerivativesContract, HasA
 from quant.pricer.binomialtree import AmericanBinomialTreePricer
 from quant.pricer.montecarlo import AmericanMonteCarloPricer
 
-class AmericanOption(DerivativesContract):
+class American(DerivativesContract):
 
     pricerClass = AmericanBinomialTreePricer
 
