@@ -8,8 +8,8 @@ def suite():
     return unittest.TestSuite(suites)
 
 
-class AmericanOptionTestCase(DerivativesContractTestCase):
+class AmericanTestCase(DerivativesContractTestCase):
 
     def getContractsRegister(self):
-        return self.registry.americanOptions
+        return self.registry.americans
 
