@@ -1,6 +1,6 @@
 from quant.dom.base import DerivativesContract, HasA
 from quant.pricer.blackscholes import EuropeanBlackScholesPricer
 
-class EuropeanOption(DerivativesContract):
+class European(DerivativesContract):
 
     pricerClass = EuropeanBlackScholesPricer
