@@ -7,8 +7,8 @@ def suite():
     ]
     return unittest.TestSuite(suites)
 
-class EuropeanOptionTestCase(DerivativesContractTestCase):
+class EuropeanTestCase(DerivativesContractTestCase):
 
     def getContractsRegister(self):
-        return self.registry.europeanOptions
+        return self.registry.europeans
 
