@@ -8,6 +8,7 @@ import quant.dom.americanoptiontest
 import quant.dom.buildertest
 import quant.dom.booktest
 import quant.dom.markettest
+import quant.dom.resulttest
 
 def suite():
     suites = [
@@ -18,6 +19,8 @@ def suite():
         quant.dom.americanoptiontest.suite(),
         quant.dom.buildertest.suite(),
         quant.dom.booktest.suite(),
+        quant.dom.markettest.suite(),
+        quant.dom.resulttest.suite(),
 
     ]
     return unittest.TestSuite(suites)
