@@ -1,4 +1,5 @@
 from quant.dom.testunit import TestCase
+import datetime
 
 class PricerTestCase(TestCase):
 
@@ -12,8 +13,8 @@ class PricerTestCase(TestCase):
     annualisedVolatility = 50
     annualRiskFreeRate = 0
     tolerance = 1e-8
-    nowTime = '2010-01-06'
-    expiryTime = '2011-01-06'
+    nowTime = datetime.datetime(2010, 1, 1)
+    expiryTime = datetime.datetime(2011, 1, 1)
 
     expectedExceptionClass = None
 
