@@ -17,9 +17,6 @@ class BinomialTreePricerTestCase(PricerTestCase):
 
     DECIMALS = 3
 
-    nowTime = '2010-01-06'
-    expiryTime = '2011-01-06'
-
 
 class TestEuropeanCall(BinomialTreePricerTestCase):
 
