@@ -15,7 +15,11 @@ class EuropeanBlackScholesPricer(AbstractOptionPricer):
         t = float(self.getOptionDurationYears())
         sigma = float(self.annualisedVolatility) / 100.0
         sigma_squared_t = sigma**2 * t
-        sigma_root_t = sigma * sqrt(t)
+        try:
+            sigma_root_t = sigma * sqrt(t)
+        except Exception, inst:
+            msg = "Couldn't sqrt: %s: %s" % (t, inst)
+            raise Exception, msg
         d1 = (log(S / K) + t * r + 0.5 * sigma_squared_t) / sigma_root_t
         d2 = d1 - sigma_root_t
         Nd1 = self.N(d1)
