@@ -17,9 +17,6 @@ class MonteCarloPricerTestCase(PricerTestCase):
 
     DECIMALS = 1
 
-    nowTime = '2010-01-06'
-    expiryTime = '2011-01-06'
-
 
 class TestEuropeanCall(MonteCarloPricerTestCase):
 
